@@ -2,5 +2,6 @@ var classFl__GDI__Printer__Graphics__Driver =
 [
     [ "class_name", "classFl__GDI__Printer__Graphics__Driver.html#a77e84db413bc16bb1ca047822df45c71", null ],
     [ "draw", "classFl__GDI__Printer__Graphics__Driver.html#af69e81e6e76074566980ac5bd1f05ddf", null ],
-    [ "draw", "classFl__GDI__Printer__Graphics__Driver.html#ac2f933377eecd101e2199e39590aa35b", null ]
+    [ "draw", "classFl__GDI__Printer__Graphics__Driver.html#ac2f933377eecd101e2199e39590aa35b", null ],
+    [ "draw_scaled", "classFl__GDI__Printer__Graphics__Driver.html#afcc1600e98a08dcbd285af451f8a5c9d", null ]
 ];
\ No newline at end of file
